{% extends 'bootstrap-italia-base.html' %}
{% load i18n %}

{% block centered_container %}
    <h4>{% trans "Error 404" %}</h4>
    <p>{% trans "Page or Resource not found 404" %}</p>
</div>
{% endblock centered_container %}
